----------------------------------------------------------------------------------------------------------------
-- Written in LUA by JeroenZeist (https://www.domoticz.com/forum/memberlist.php?mode=viewprofile&u=6788)
-- Summer 2015
-- 07-08-2015 v1.0 Initial release
-- 07-12-2015 v1.1 Added option to monitor availability of Intergas module. Thanks to wimd68
-- script_time_intergasincomfort.lua
-- Requires:
-- - Intergas Incomfort Gateway
-- - Virtual devices in Domoticz:
 -- - Temperature sensor for current temperature
 -- - Temperature sensor for current temperature setpoint
 -- - Virtual thermostat for temperature setpoint
----------------------------------------------------------------------------------------------------------------

-- config ------------------------------------------------------------------------------------------------------
local debug = true -- false or true, true gives extra output in Domoticz log
lan2rf = '192.168.1.206' -- ip address of the Intergas Incomfort Lan2RF gateway
domoticzaddress = '192.168.1.12' -- ip address of Domoticz
tempfilename = '/var/tmp/thermostat.tmp' -- could be anywhere as long as it is writeable

local idxt = 6 --idx of the virtual temperature sensor you need to change this to your own Device IDx
local currenttempname = "Woonkamer huidig" -- name of the virtual temperature sensor

local idxset = 7 -- idx for set temperature on the physical thermostat
local currentlyset = "Woonkamer ingesteld" -- name of the virtual set temperature on the physical thermostat

local idxsetthermostat = 8 -- idx of the virtual thermostat in Domoticz
local thermostatname = "Thermostaat" -- name of the virtual thermostat in Domoticz

local idxLive = 72   -- idx of the virtual switch that shows if the intergas module is alive
local isalivename= "Intergas Module"  -- name of the virtual switch whether the Intergas module is online

-- Loading required modules ------------------------------------------------------------------------------------
local io = require "io" -- loading io modules
if debug then print("Loaded IO modules") end
JSON = assert(loadfile "/home/pi/domoticz/scripts/lua/JSON.lua")() -- one-time load of the JSON routines
if debug then print("Loaded JSON routines") end

-- Functions ---------------------------------------------------------------------------------------------------
function UpdateHeaterData() -- Gets heater data json and updates the temp file
	url='http://'..lan2rf..'/data.json?heater=0'
	if debug then print("URL of heater data: "..url) end
	
	read = os.execute('curl -s -S -o '..tempfilename..' "'..url..'"')
	if read then
		print ("Status Intergas module gelezen")
		if (otherdevices[isalivename]=='Off') then
			commandArray[isalivename]='On'
			print ("Intergas Module turns on")
		end
	else
		if (otherdevices[isalivename]=='On') then
			commandArray[isalivename]='Off'
			print ("Intergas Module goes down")
		end
	end
	
	
	local prevtext = ""
	for line in io.lines(tempfilename) do
		text = prevtext .. line 
		prevtext = text
	end
	if debug then print(text) end
	lua_heater_data = JSON:decode(text) -- decode RAW JSON data into LUA data
	if debug then print("lsb: "..lua_heater_data.room_temp_1_lsb) end
	if debug then print("msb: "..lua_heater_data.room_temp_1_msb) end
end

function GetCurrentTemperature()
	local currenttemp = (lua_heater_data.room_temp_1_lsb+lua_heater_data.room_temp_1_msb*256)/100 -- calculate current temperature
	print("Current temperature: "..currenttemp)
	return currenttemp
end -- GetCurrentTemperature

function UpdateCurrentTemperature()
	if GetCurrentTemperature() + 0.01 ~= otherdevices_svalues[currenttempname] + 0.01 then
			if debug then print("Current temperature changed") end
			commandArray[1] = {['UpdateDevice'] = idxt .. '|0|' .. GetCurrentTemperature()}
	end
end

function GetSetTemperature()
	local settemp = (lua_heater_data.room_temp_set_1_lsb+lua_heater_data.room_temp_set_1_msb*256)/100 -- calculates currently set temperature
	print("Currently set temperature: "..settemp)
	return settemp
end -- GetSetTemperature

function UpdateSetTemperature()
	if GetSetTemperature() + 0.01 ~= otherdevices_svalues[currentlyset] + 0.01 then
			if debug then print("Temperature setpoint changed") end
			commandArray[2] = {['UpdateDevice'] = idxset .. '|0|' .. GetSetTemperature()}
	end
end

-- Incomfort -----------------------------------------------------------------------------------------------------
commandArray = {}
UpdateHeaterData()
UpdateCurrentTemperature()
UpdateSetTemperature()
return commandArray 